import path from 'node:path';

var bundleToWebpackStats = function bundleToWebpackStats(bundle) {
  var items = Object.values(bundle);
  var assets = [];
  var chunks = [];
  var moduleByFileName = {};
  items.forEach(function (item) {
    if (item.type === 'chunk') {
      var _item$code;
      assets.push({
        name: item.fileName,
        size: (_item$code = item.code) == null ? void 0 : _item$code.length
      });
      var chunkId = item.name;
      chunks.push({
        id: chunkId,
        entry: item.isEntry,
        initial: false,
        files: [item.fileName],
        names: [item.name]
      });
      Object.entries(item.modules).forEach(function (_ref) {
        var modulePath = _ref[0],
          moduleInfo = _ref[1];
        var relativeModulePath = path.relative(process.cwd(), modulePath.replace("\0", ''));
        var moduleEntry = moduleByFileName[relativeModulePath];
        if (moduleEntry) {
          moduleEntry.chunks.push(chunkId);
        } else {
          moduleByFileName[relativeModulePath] = {
            name: relativeModulePath,
            size: moduleInfo.originalLength,
            chunks: [chunkId]
          };
        }
      });
    } else {
      var _item$source;
      assets.push({
        name: item.fileName,
        size: (_item$source = item.source) == null ? void 0 : _item$source.length
      });
    }
  });
  var output = {
    assets: assets,
    chunks: chunks,
    modules: Object.values(moduleByFileName)
  };
  return output;
};

var NAME = 'webpackStats';
var webpackStats = function webpackStats() {
  return {
    name: NAME,
    generateBundle: function generateBundle(_, bundle) {
      var output = bundleToWebpackStats(bundle);
      this.emitFile({
        type: 'asset',
        fileName: 'webpack-stats.json',
        source: JSON.stringify(output)
      });
    }
  };
};

export { webpackStats };
//# sourceMappingURL=rollup-plugin-webpack-stats.esm.js.map
